"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.order = void 0;
const appearance_1 = require("./group/appearance");
const box_model_1 = require("./group/box_model");
const interaction_1 = require("./group/interaction");
const layout_1 = require("./group/layout");
const positioning_1 = require("./group/positioning");
const svg_1 = require("./group/svg");
const transition_1 = require("./group/transition");
const typography_1 = require("./group/typography");
const propertyGroups = [
    ['composes'],
    ['all'],
    interaction_1.interaction,
    positioning_1.positioning,
    layout_1.layout,
    box_model_1.boxModel,
    typography_1.typography,
    appearance_1.appearance,
    svg_1.svg,
    transition_1.transition
];
const propertiesOrder = propertyGroups.map((properties) => ({
    emptyLineBefore: 'never',
    noEmptyLineBetween: true,
    properties
}));
const order = {
    plugins: ['stylelint-order'],
    rules: {
        'order/order': [
            [
                {
                    name: 'import',
                    type: 'at-rule'
                },
                {
                    name: 'forward',
                    type: 'at-rule'
                },
                {
                    name: 'use',
                    type: 'at-rule'
                },
                'dollar-variables',
                'at-variables',
                'custom-properties',
                {
                    name: 'custom-media',
                    type: 'at-rule'
                },
                {
                    name: 'function',
                    type: 'at-rule'
                },
                {
                    name: 'mixin',
                    type: 'at-rule'
                },
                {
                    name: 'extend',
                    type: 'at-rule'
                },
                {
                    name: 'include',
                    type: 'at-rule'
                },
                'declarations',
                {
                    hasBlock: true,
                    selector: /^&::[\w-]+/u,
                    type: 'rule'
                },
                'rules',
                {
                    hasBlock: true,
                    name: 'media',
                    type: 'at-rule'
                }
            ],
            {
                severity: 'warning'
            }
        ],
        'order/properties-order': [
            propertiesOrder,
            {
                emptyLineBeforeUnspecified: 'always',
                emptyLineMinimumPropertyThreshold: 5,
                severity: 'warning',
                unspecified: 'bottomAlphabetical'
            }
        ]
    }
};
exports.order = order;
//# sourceMappingURL=order.js.map